@@ -1,10 +1,18 @@
+"""
+***************************
+Synapse command line client
+***************************
+
+For help, type synapse -h.
+
+"""
 import argparse
 import os
 import shutil
 import sys
 import synapseclient
 from synapseclient import Activity
-import version_check
+import utils
 import signal
 import json
 
@@ -76,7 +84,8 @@ def delete(args, syn):
     Arguments:
     - `args`:
     """
-    ent = syn.deleteEntity(args.id)
+    syn.deleteEntity(args.id)
+    sys.stderr.write('Deleted entity: %s\n' % args.id)
 
     
 def upload(args, syn):
@@ -86,13 +95,14 @@ def upload(args, syn):
     - `args`:
     """
     if args.type == 'File': args.type = 'FileEntity'
-    entity={'name': args.name, 
-            'parentId': args.parentid, 
-            'description':args.description, 
+    entity={'name': args.name,
+            'parentId': args.parentid,
+            'description':args.description,
             'entityType': u'org.sagebionetworks.repo.model.%s' %args.type}
-    entity = syn.createEntity(entity, args.used, args.executed)
-    entity = syn.uploadFile(entity, args.file)
-    sys.stderr.write('Created entity: %s\t%s from file: %s\n' %(entity['id'],entity['name'], args.file))
+
+    entity = syn.uploadFile(entity, args.file, used=args.used, executed=args.executed)
+
+    sys.stderr.write('Created entity: %s\t%s from file: %s\n' %(entity['id'], entity['name'], args.file))
     return(entity)
 
 
@@ -175,6 +185,8 @@ def main():
     parser.add_argument('--version', action='version', version='Synapse Client %s' % synapseclient.__version__)
     parser.add_argument('-u', '--username', dest='synapseUser', help='Username used to connect to Synapse')
     parser.add_argument('-p', '--password', dest='synapsePassword', help='Password used to connect to Synapse')
+    parser.add_argument('--debug', dest='debug', action='store_true')
+
 
     subparsers = parser.add_subparsers(title='subcommands', description='valid subcommands',
                                        help='additional help')
@@ -209,7 +221,7 @@ def main():
     parser_add.add_argument('-parentid', '-parentId', metavar='syn123', type=str, required=True, 
                          help='Synapse ID of project or folder where to upload data.')
     #TODO make so names can have white space
-    parser_add.add_argument('-name', metavar='NAME', type=str, required=True,
+    parser_add.add_argument('-name', metavar='NAME', type=str, required=False,
                          help='Name of data object in Synapse')
     #TODO make sure that description can have whitespace
     parser_add.add_argument('-description', metavar='DESCRIPTION', type=str, 
@@ -287,12 +299,19 @@ def main():
 
     #TODO Perform proper login either prompt for info or use parameters
     ## if synapseUser and synapsePassword are not given, try to use cached session token
-    syn = synapseclient.Synapse(debug=False)
+    syn = synapseclient.Synapse(debug=args.debug)
     syn.login(args.synapseUser, args.synapsePassword)
 
     #Perform the requested action
     if 'func' in args:
-        args.func(args, syn)
+        try:
+            args.func(args, syn)
+        except Exception as ex:
+            sys.stderr.write(utils.synapse_error_msg(ex))
+
+            if args.debug:
+                raise
+
 
 
 ## call main method if this file is run as a script
