@@ -2,15 +2,13 @@
 ##
 ############################################################
 from distutils.version import StrictVersion
-from utils import downloadFile
 import requests
 import json
 import sys
-import traceback
-import warnings
 import pkg_resources
 
 
+
 _VERSION_URL     = 'http://versions.synapse.sagebase.org/synapsePythonClient'
 _DEV_VERSION_URL = 'http://dev-versions.synapse.sagebase.org/synapsePythonClient'
 _UPGRADE_URL     = 'https://github.com/Sage-Bionetworks/synapsePythonClient'
